<?php
if ( ! defined('F')) exit('Нет доступа!');
/*
 * @class IPGeoBase
 * @brief Класс для работы с текстовыми базами ipgeobase.ru
 * @see example.php
 *
 * Определяет страну, регион и город по IP для России и Украины
 */
class IPGeoBase 
{
	private $fhandleCIDR, $fhandleCities, $fSizeCIDR, $fsizeCities;
	function __construct($CIDRFile = false, $CitiesFile = false)
	{
		if(!$CIDRFile)
		{
			$CIDRFile = dirname(__FILE__) . '/cidr_optim.txt';			
		}
		if(!$CitiesFile)
		{
			$CitiesFile = dirname(__FILE__) . '/cities.txt';			
		}
		$this->fhandleCIDR = fopen($CIDRFile, 'r') or die("Cannot open");
		$this->fhandleCities = fopen($CitiesFile, 'r') or die("Cannot open");
		$this->fSizeCIDR = filesize($CIDRFile);
		$this->fsizeCities = filesize($CitiesFile);	
	}

    /*
     * @brief Получение информации о городе по индексу
     * @param idx индекс города
     * @return массив или false, если не найдено
     */
	private function getCityByIdx($idx)
	{
		rewind($this->fhandleCities);
		while(!feof($this->fhandleCities))
		{
			$str = fgets($this->fhandleCities);
			$arRecord = explode("\t", trim($str));
			if($arRecord[0] == $idx)
			{
				return array(	
					'city_id' => $arRecord[0],
					'city' => $arRecord[1],
					'region' => $arRecord[2],
					'district' => $arRecord[3],
					'lat' => $arRecord[4],
					'lng' => $arRecord[5]);
			}
		}
		return false;
	}
	private function getCityByTitle($city)
	{
		$city = mb_strtolower(trim($city));
		rewind($this->fhandleCities);
		while(!feof($this->fhandleCities))
		{
			$str = fgets($this->fhandleCities);
			$arRecord = explode("\t", trim($str));
			if(mb_strtolower(trim($arRecord[1])) == $city)
			{
				return array(	
					'id' => $arRecord[0],
					'city' => $arRecord[1],
					'region' => $arRecord[2],
					'district' => $arRecord[3],
					'lat' => $arRecord[4],
					'lng' => $arRecord[5]);
			}
		}
		return false;
	}


	/*function diapazonByCity($city)
	{
		$ret = array();
		$t = $this->getCityByTitle($city);
		if(empty($t))
			return $ret;
		$city_id = $t['id'];
		unset($t);


		rewind($this->fhandleCIDR);

	    while (($buffer = fgets($this->fhandleCIDR)) !== false) {
			$arRecord = explode("\t", trim($str));
			if($arRecord[4] == $t)
				array_push($ret, array('start'=>$arRecord[0],'end'=>$arRecord[1]));
	    }
        return $ret;
	}*/

    /*
     * @brief Получение гео-информации по IP
     * @param ip IPv4-адрес
     * @return массив или false, если не найдено
     */

	function getRecord($ip, $ind = 0)
	{
		$ip = sprintf('%u', ip2long($ip));
		
		rewind($this->fhandleCIDR);
		$rad = floor($this->fSizeCIDR / 2);
		$pos = $rad;
		while(fseek($this->fhandleCIDR, $pos, SEEK_SET) != -1)			
		{
			if($rad) 
			{
				$str = fgets($this->fhandleCIDR);				
			}
			else
			{
				rewind($this->fhandleCIDR);
			}
			
			$str = fgets($this->fhandleCIDR);
			
			if(!$str)
			{
				return false;
			}
			
			$arRecord = explode("\t", trim($str));

			$rad = floor($rad / 2);
			if(!$rad && ($ip < $arRecord[0] || $ip > $arRecord[1]))
			{
				return false;
			}
			
			if($ip < $arRecord[0])
			{
				$pos -= $rad;
			}
			elseif($ip > $arRecord[1])
			{
				$pos += $rad;
			}
			else
			{
				if($ind){
					$r_ind = ($arRecord[4] != '-') ? (int)$arRecord[4] : 0;
					return array('reg_index' => $r_ind, 'cc' => $arRecord[3]);
				}
				else{
					$result = array('range' => $arRecord[2], 'cc' => $arRecord[3]);
												
					if($arRecord[4] != '-' && $cityResult = $this->getCityByIdx($arRecord[4]))
					{
						$result += $cityResult;
					}
					$ar_country = $this->getCountriTitle();
					$result['country'] = isset($ar_country[$result['cc']]) ? $ar_country[$result['cc']] : '';
					return $result;
				}
			}
		}
		return false;		
	}
	public function getCountriTitle(){
		return array(
		    'RU' => 'Россия',
		    'BY' => 'Белоруссия',
		    'UA' => 'Украина',
		    'KZ' => 'Казахстан',
		    'AU' => 'Австралия',
		    'AT' => 'Австрия',
		    'AZ' => 'Азербайджан',
		    'AX' => 'Аландские острова',
		    'AL' => 'Албания',
		    'DZ' => 'Алжир',
		    'VI' => 'Американские Виргинские острова',
		    'AS' => 'Американское Самоа',
		    'AI' => 'Ангилья',
		    'AO' => 'Ангола',
		    'AD' => 'Андорра',
		    'AQ' => 'Антарктида',
		    'AG' => 'Антигуа и Барбуда',
		    'AR' => 'Аргентина',
		    'AM' => 'Армения',
		    'AW' => 'Аруба',
		    'AF' => 'Афганистан',
		    'BS' => 'Багамы',
		    'BD' => 'Бангладеш',
		    'BB' => 'Барбадос',
		    'BH' => 'Бахрейн',
		    'BZ' => 'Белиз',
		    //'BY' => 'Белоруссия',
		    'BE' => 'Бельгия',
		    'BJ' => 'Бенин',
		    'BM' => 'Бермуды',
		    'BG' => 'Болгария',
		    'BO' => 'Боливия',
		    'BQ' => 'Бонэйр, Синт-Эстатиус и Саба',
		    'BA' => 'Босния и Герцеговина',
		    'BW' => 'Ботсвана',
		    'BR' => 'Бразилия',
		    'IO' => 'Британская территория в Индийском океане',
		    'VG' => 'Британские Виргинские острова',
		    'BN' => 'Бруней',
		    'BF' => 'Буркина-Фасо',
		    'BI' => 'Бурунди',
		    'BT' => 'Бутан',
		    'VU' => 'Вануату',
		    'VA' => 'Ватикан',
		    'GB' => 'Великобритания',
		    'HU' => 'Венгрия',
		    'VE' => 'Венесуэла',
		    'UM' => 'Внешние малые острова (США)',
		    'TL' => 'Восточный Тимор',
		    'VN' => 'Вьетнам',
		    'GA' => 'Габон',
		    'HT' => 'Гаити',
		    'GY' => 'Гайана',
		    'GM' => 'Гамбия',
		    'GH' => 'Гана',
		    'GP' => 'Гваделупа',
		    'GT' => 'Гватемала',
		    'GF' => 'Гвиана',
		    'GN' => 'Гвинея',
		    'GW' => 'Гвинея-Бисау',
		    'DE' => 'Германия',
		    'GG' => 'Гернси',
		    'GI' => 'Гибралтар',
		    'HN' => 'Гондурас',
		    'HK' => 'Гонконг',
		    'GD' => 'Гренада',
		    'GL' => 'Гренландия',
		    'GR' => 'Греция',
		    'GE' => 'Грузия',
		    'GU' => 'Гуам',
		    'DK' => 'Дания',
		    'JE' => 'Джерси',
		    'DJ' => 'Джибути',
		    'DM' => 'Доминика',
		    'DO' => 'Доминиканская Республика',
		    'CD' => 'ДР Конго',
		    'EU' => 'Европейский союз',
		    'EG' => 'Египет',
		    'ZM' => 'Замбия',
		    'EH' => 'Западная Сахара',
		    'ZW' => 'Зимбабве',
		    'IL' => 'Израиль',
		    'IN' => 'Индия',
		    'ID' => 'Индонезия',
		    'JO' => 'Иордания',
		    'IQ' => 'Ирак',
		    'IR' => 'Иран',
		    'IE' => 'Ирландия',
		    'IS' => 'Исландия',
		    'ES' => 'Испания',
		    'IT' => 'Италия',
		    'YE' => 'Йемен',
		    'CV' => 'Кабо-Верде',
		    //'KZ' => 'Казахстан',
		    'KY' => 'Каймановы острова',
		    'KH' => 'Камбоджа',
		    'CM' => 'Камерун',
		    'CA' => 'Канада',
		    'QA' => 'Катар',
		    'KE' => 'Кения',
		    'CY' => 'Кипр',
		    'KG' => 'Киргизия',
		    'KI' => 'Кирибати',
		    'TW' => 'Китайская Республика',
		    'KP' => 'КНДР',
		    'CN' => 'КНР',
		    'CC' => 'Кокосовые острова',
		    'CO' => 'Колумбия',
		    'KM' => 'Коморы',
		    'CR' => 'Коста-Рика',
		    'CI' => 'Кот-д’Ивуар',
		    'CU' => 'Куба',
		    'KW' => 'Кувейт',
		    'CW' => 'Кюрасао',
		    'LA' => 'Лаос',
		    'LV' => 'Латвия',
		    'LS' => 'Лесото',
		    'LR' => 'Либерия',
		    'LB' => 'Ливан',
		    'LY' => 'Ливия',
		    'LT' => 'Литва',
		    'LI' => 'Лихтенштейн',
		    'LU' => 'Люксембург',
		    'MU' => 'Маврикий',
		    'MR' => 'Мавритания',
		    'MG' => 'Мадагаскар',
		    'YT' => 'Майотта',
		    'MO' => 'Макао',
		    'MK' => 'Македония',
		    'MW' => 'Малави',
		    'MY' => 'Малайзия',
		    'ML' => 'Мали',
		    'MV' => 'Мальдивы',
		    'MT' => 'Мальта',
		    'MA' => 'Марокко',
		    'MQ' => 'Мартиника',
		    'MH' => 'Маршалловы Острова',
		    'MX' => 'Мексика',
		    'FM' => 'Микронезия',
		    'MZ' => 'Мозамбик',
		    'MD' => 'Молдавия',
		    'MC' => 'Монако',
		    'MN' => 'Монголия',
		    'MS' => 'Монтсеррат',
		    'MM' => 'Мьянма',
		    'NA' => 'Намибия',
		    'NR' => 'Науру',
		    'NP' => 'Непал',
		    'NE' => 'Нигер',
		    'NG' => 'Нигерия',
		    'NL' => 'Нидерланды',
		    'NI' => 'Никарагуа',
		    'NU' => 'Ниуэ',
		    'NZ' => 'Новая Зеландия',
		    'NC' => 'Новая Каледония',
		    'NO' => 'Норвегия',
		    'AE' => 'ОАЭ',
		    'OM' => 'Оман',
		    'BV' => 'Остров Буве',
		    'IM' => 'Остров Мэн',
		    'CK' => 'Острова Кука',
		    'NF' => 'Остров Норфолк',
		    'CX' => 'Остров Рождества',
		    'PN' => 'Острова Питкэрн',
		    'SH' => 'Острова Святой Елены, Вознесения и Тристан-да-Кунья',
		    'PK' => 'Пакистан',
		    'PW' => 'Палау',
		    'PS' => 'Палестинская национальная администрация',
		    'PA' => 'Панама',
		    'PG' => 'Папуа — Новая Гвинея',
		    'PY' => 'Парагвай',
		    'PE' => 'Перу',
		    'PL' => 'Польша',
		    'PT' => 'Португалия',
		    'PR' => 'Пуэрто-Рико',
		    'CG' => 'Республика Конго',
		    'KR' => 'Республика Корея',
		    'RE' => 'Реюньон',
		    //'RU' => 'Россия',
		    'RW' => 'Руанда',
		    'RO' => 'Румыния',
		    'SV' => 'Сальвадор',
		    'WS' => 'Самоа',
		    'SM' => 'Сан-Марино',
		    'ST' => 'Сан-Томе и Принсипи',
		    'SA' => 'Саудовская Аравия',
		    'SZ' => 'Свазиленд',
		    'MP' => 'Северные Марианские острова',
		    'SC' => 'Сейшельские Острова',
		    'BL' => 'Сен-Бартелеми',
		    'MF' => 'Сен-Мартен',
		    'PM' => 'Сен-Пьер и Микелон',
		    'SN' => 'Сенегал',
		    'VC' => 'Сент-Винсент и Гренадины',
		    'KN' => 'Сент-Китс и Невис',
		    'LC' => 'Сент-Люсия',
		    'RS' => 'Сербия',
		    'SG' => 'Сингапур',
		    'SX' => 'Синт-Мартен',
		    'SY' => 'Сирия',
		    'SK' => 'Словакия',
		    'SI' => 'Словения',
		    'SB' => 'Соломоновы Острова',
		    'SO' => 'Сомали',
		    'SD' => 'Судан',
		    'SU' => 'СССР',
		    'SR' => 'Суринам',
		    'US' => 'США',
		    'SL' => 'Сьерра-Леоне',
		    'TJ' => 'Таджикистан',
		    'TH' => 'Таиланд',
		    'TZ' => 'Танзания',
		    'TC' => 'Тёркс и Кайкос',
		    'TG' => 'Того',
		    'TK' => 'Токелау',
		    'TO' => 'Тонга',
		    'TT' => 'Тринидад и Тобаго',
		    'TV' => 'Тувалу',
		    'TN' => 'Тунис',
		    'TM' => 'Туркмения',
		    'TR' => 'Турция',
		    'UG' => 'Уганда',
		    'UZ' => 'Узбекистан',
		    //'UA' => 'Украина',
		    'WF' => 'Уоллис и Футуна',
		    'UY' => 'Уругвай',
		    'FO' => 'Фарерские острова',
		    'FJ' => 'Фиджи',
		    'PH' => 'Филиппины',
		    'FI' => 'Финляндия',
		    'FK' => 'Фолклендские острова',
		    'FR' => 'Франция',
		    'PF' => 'Французская Полинезия',
		    'TF' => 'Французские Южные и Антарктические Территории',
		    'HM' => 'Херд и Макдональд',
		    'HR' => 'Хорватия',
		    'CF' => 'ЦАР',
		    'TD' => 'Чад',
		    'ME' => 'Черногория',
		    'CZ' => 'Чехия',
		    'CL' => 'Чили',
		    'CH' => 'Швейцария',
		    'SE' => 'Швеция',
		    'SJ' => 'Шпицберген и Ян-Майен',
		    'LK' => 'Шри-Ланка',
		    'EC' => 'Эквадор',
		    'GQ' => 'Экваториальная Гвинея',
		    'ER' => 'Эритрея',
		    'EE' => 'Эстония',
		    'ET' => 'Эфиопия',
		    'ZA' => 'ЮАР',
		    'GS' => 'Южная Георгия и Южные Сандвичевы острова',
		    'SS' => 'Южный Судан',
		    'JM' => 'Ямайка',
		    'JP' => 'Япония');

/***************** добавить валюты и язык
'AED' => array('Title' => 'Дирхам (ОАЭ)'),
'AFN' => array('Title' => 'Афгани'),
'ALL' => array('Title' => 'Лек'),
'AMD' => array('Title' => 'Армянский драм'),
'ANG' => array('Title' => 'Нидерландский антильский гульден'),
'AOA' => array('Title' => 'Кванза'),
'ARS' => array('Title' => 'Аргентинское песо'),
'AUD' => array('Title' => 'Австралийский доллар'),
'AWG' => array('Title' => 'Арубанский флорин[15]'),
'AZN' => array('Title' => 'Азербайджанский манат'),
'BAM' => array('Title' => 'Конвертируемая марка'),
'BBD' => array('Title' => 'Барбадосский доллар'),
'BDT' => array('Title' => 'Така'),
'BGN' => array('Title' => 'Болгарский лев'),
'BHD' => array('Title' => 'Бахрейнский динар'),
'BIF' => array('Title' => 'Бурундийский франк'),
'BMD' => array('Title' => 'Бермудский доллар'),
'BND' => array('Title' => 'Брунейский доллар'),
'BOB' => array('Title' => 'Боливиано'),
'BOV' => array('Title' => 'Мвдол[16]'),
'BRL' => array('Title' => 'Бразильский реал'),
'BSD' => array('Title' => 'Багамский доллар'),
'BTN' => array('Title' => 'Нгултрум'),
'BWP' => array('Title' => 'Пула'),
'BYN' => array('Title' => 'Белорусский рубль'),
'BZD' => array('Title' => 'Белизский доллар'),
'CAD' => array('Title' => 'Канадский доллар'),
'CDF' => array('Title' => 'Конголезский франк'),
'CHE' => array('Title' => 'WIR-евро[16]'),
'CHF' => array('Title' => 'Швейцарский франк'),
'CHW' => array('Title' => 'WIR-франк[16]'),
'CLF' => array('Title' => 'Единица развития[en][16]'),
'CLP' => array('Title' => 'Чилийское песо'),
'CNY' => array('Title' => 'Юань'),
'COP' => array('Title' => 'Колумбийское песо'),
'COU' => array('Title' => 'Единица реальной стоимости[16]'),
'CRC' => array('Title' => 'Коста-риканский колон'),
'CUC' => array('Title' => 'Конвертируемое песо'),
'CUP' => array('Title' => 'Кубинское песо'),
'CVE' => array('Title' => 'Эскудо Кабо-Верде'),
'CZK' => array('Title' => 'Чешская крона'),
'DJF' => array('Title' => 'Франк Джибути'),
'DKK' => array('Title' => 'Датская крона'),
'DOP' => array('Title' => 'Доминиканское песо'),
'DZD' => array('Title' => 'Алжирский динар'),
'EGP' => array('Title' => 'Египетский фунт'),
'ERN' => array('Title' => 'Накфа'),
'ETB' => array('Title' => 'Эфиопский быр'),
'EUR' => array('Title' => 'Евро'),
'FJD' => array('Title' => 'Доллар Фиджи'),
'FKP' => array('Title' => 'Фунт Фолклендских островов'),
'GBP' => array('Title' => 'Фунт стерлингов'),
'GEL' => array('Title' => 'Лари'),
'GHS' => array('Title' => 'Ганский седи'),
'GIP' => array('Title' => 'Гибралтарский фунт'),
'GMD' => array('Title' => 'Даласи'),
'GNF' => array('Title' => 'Гвинейский франк'),
'GTQ' => array('Title' => 'Кетсаль'),
'GYD' => array('Title' => 'Гайанский доллар'),
'HKD' => array('Title' => 'Гонконгский доллар'),
'HNL' => array('Title' => 'Лемпира'),
'HRK' => array('Title' => 'Хорватская куна'),
'HTG' => array('Title' => 'Гурд'),
'HUF' => array('Title' => 'Форинт'),
'IDR' => array('Title' => 'Рупия'),
'ILS' => array('Title' => 'Новый израильский шекель'),
'INR' => array('Title' => 'Индийская рупия'),
'IQD' => array('Title' => 'Иракский динар'),
'IRR' => array('Title' => 'Иранский риал'),
'ISK' => array('Title' => 'Исландская крона'),
'JMD' => array('Title' => 'Ямайский доллар'),
'JOD' => array('Title' => 'Иорданский динар'),
'JPY' => array('Title' => 'Иена'),
'KES' => array('Title' => 'Кенийский шиллинг'),
'KGS' => array('Title' => 'Сом'),
'KHR' => array('Title' => 'Риель'),
'KMF' => array('Title' => 'Франк Комор'),
'KPW' => array('Title' => 'Северокорейская вона'),
'KRW' => array('Title' => 'Вона'),
'KWD' => array('Title' => 'Кувейтский динар'),
'KYD' => array('Title' => 'Доллар Островов Кайман'),
'KZT' => array('Title' => 'Тенге'),
'LAK' => array('Title' => 'Кип'),
'LBP' => array('Title' => 'Ливанский фунт'),
'LKR' => array('Title' => 'Шри-ланкийская рупия'),
'LRD' => array('Title' => 'Либерийский доллар'),
'LSL' => array('Title' => 'Лоти'),
'LTL' => array('Title' => 'Литовский лит'),
'LYD' => array('Title' => 'Ливийский динар'),
'MAD' => array('Title' => 'Марокканский дирхам'),
'MDL' => array('Title' => 'Молдавский лей'),
'MGA' => array('Title' => 'Малагасийский ариари'),
'MKD' => array('Title' => 'Денар'),
'MMK' => array('Title' => 'Кьят'),
'MNT' => array('Title' => 'Тугрик'),
'MOP' => array('Title' => 'Патака'),
'MRU' => array('Title' => 'Угия'),
'MUR' => array('Title' => 'Маврикийская рупия'),
'MVR' => array('Title' => 'Руфия'),
'MWK' => array('Title' => 'Квача'),
'MXN' => array('Title' => 'Мексиканское песо'),
'MXV' => array('Title' => 'Мексиканская инверсионная единица[en][16]'),
'MYR' => array('Title' => 'Малайзийский ринггит'),
'MZN' => array('Title' => 'Мозамбикский метикал'),
'NAD' => array('Title' => 'Доллар Намибии'),
'NGN' => array('Title' => 'Найра'),
'NIO' => array('Title' => 'Золотая кордоба'),
'NOK' => array('Title' => 'Норвежская крона'),
'NPR' => array('Title' => 'Непальская рупия'),
'NZD' => array('Title' => 'Новозеландский доллар'),
'OMR' => array('Title' => 'Оманский риал'),
'PAB' => array('Title' => 'Бальбоа'),
'PEN' => array('Title' => 'Новый соль'),
'PGK' => array('Title' => 'Кина'),
'PHP' => array('Title' => 'Филиппинское песо'),
'PKR' => array('Title' => 'Пакистанская рупия'),
'PLN' => array('Title' => 'Злотый'),
'PYG' => array('Title' => 'Гуарани'),
'QAR' => array('Title' => 'Катарский риал'),
'RON' => array('Title' => 'Новый румынский лей'),
'RSD' => array('Title' => 'Сербский динар'),
'RUB' => array('Title' => 'Российский рубль'),
'RWF' => array('Title' => 'Франк Руанды'),
'SAR' => array('Title' => 'Саудовский риял'),
'SBD' => array('Title' => 'Доллар Соломоновых Островов'),
'SCR' => array('Title' => 'Сейшельская рупия'),
'SDG' => array('Title' => 'Суданский фунт'),
'SEK' => array('Title' => 'Шведская крона'),
'SGD' => array('Title' => 'Сингапурский доллар'),
'SHP' => array('Title' => 'Фунт Святой Елены'),
'SLL' => array('Title' => 'Леоне'),
'SOS' => array('Title' => 'Сомалийский шиллинг'),
'SRD' => array('Title' => 'Суринамский доллар'),
'SSP' => array('Title' => 'Южносуданский фунт'),
'STN' => array('Title' => 'Добра'),
'SVC' => array('Title' => 'Сальвадорский колон'),
'SYP' => array('Title' => 'Сирийский фунт'),
'SZL' => array('Title' => 'Лилангени'),
'THB' => array('Title' => 'Бат'),
'TJS' => array('Title' => 'Сомони'),
'TMT' => array('Title' => 'Новый туркменский манат'),
'TND' => array('Title' => 'Тунисский динар'),
'TOP' => array('Title' => 'Паанга'),
'TRY' => array('Title' => 'Турецкая лира'),
'TTD' => array('Title' => 'Доллар Тринидада и Тобаго'),
'TWD' => array('Title' => 'Новый тайваньский доллар'),
'TZS' => array('Title' => 'Танзанийский шиллинг'),
'UAH' => array('Title' => 'Гривна'),
'UGX' => array('Title' => 'Угандийский шиллинг'),
'USD' => array('Title' => 'Доллар США'),
'USN' => array('Title' => 'Доллар следующего дня[16]'),
'USS' => array('Title' => 'Доллар того же дня[16]'),
'UYI' => array('Title' => 'Уругвайское песо в индексированных единицах[16]'),
'UYU' => array('Title' => 'Уругвайское песо'),
'UZS' => array('Title' => 'Узбекский сум'),
'VEF' => array('Title' => 'Боливар фуэрте'),
'VND' => array('Title' => 'Донг'),
'VUV' => array('Title' => 'Вату'),
'WST' => array('Title' => 'Тала'),
'XAF' => array('Title' => 'Франк КФА BEAC'),
'XAG' => array('Title' => 'Серебро (тройская унция)'),
'XAU' => array('Title' => 'Золото (тройская унция)'),
'XBA' => array('Title' => 'Европейская составная единица EURCO[en]'),
'XBB' => array('Title' => 'Европейская валютная единица EMU-6[en]'),
'XBC' => array('Title' => 'Европейская расчётная единица EUA-9[en]'),
'XBD' => array('Title' => 'Европейская расчётная единица EUA-17[en]'),
'XCD' => array('Title' => 'Восточно-карибский доллар'),
'XDR' => array('Title' => 'СДР (специальные права заимствования)'),
'XFU' => array('Title' => 'Франк UIC[en]'),
'XOF' => array('Title' => 'Франк КФА BCEAO'),
'XPD' => array('Title' => 'Палладий (тройская унция)'),
'XPF' => array('Title' => 'Франк КФП'),
'XPT' => array('Title' => 'Платина (тройская унция)'),
'XSU' => array('Title' => 'Сукре'),
'XTS' => array('Title' => 'Тестовый код[32]'),
'XUA' => array('Title' => 'Расчётная единица ADB'),
'XXX' => array('Title' => 'Без валюты[34]'),
'YER' => array('Title' => 'Йеменский риал'),
'ZAR' => array('Title' => 'Рэнд'),
'ZMW' => array('Title' => 'Замбийская квача[35]'),
'ZWL' => array('Title' => 'Доллар Зимбабве'),
*/
	}
}

